<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 */
function optionsframework_option_name() {
	// Change this to use your theme slug
	return 'options-framework-theme';
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'theme-textdomain'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {

	// Test data
	$test_array = array(
		'one' => __( 'One', 'theme-textdomain' ),
		'two' => __( 'Two', 'theme-textdomain' ),
		'three' => __( 'Three', 'theme-textdomain' ),
		'four' => __( 'Four', 'theme-textdomain' ),
		'five' => __( 'Five', 'theme-textdomain' )
	);

	// Multicheck Array
	$multicheck_array = array(
		'one' => __( 'French Toast', 'theme-textdomain' ),
		'two' => __( 'Pancake', 'theme-textdomain' ),
		'three' => __( 'Omelette', 'theme-textdomain' ),
		'four' => __( 'Crepe', 'theme-textdomain' ),
		'five' => __( 'Waffle', 'theme-textdomain' )
	);

	// Multicheck Defaults
	$multicheck_defaults = array(
		'one' => '1',
		'five' => '1'
	);

	// Background Defaults
	$background_defaults = array(
		'color' => '',
		'image' => '',
		'repeat' => 'repeat',
		'position' => 'top center',
		'attachment'=>'scroll' );

	// Typography Defaults
	$typography_defaults = array(
		'size' => '15px',
		'face' => 'georgia',
		'style' => 'bold',
		'color' => '#bada55' );

	// Typography Options
	$typography_options = array(
		'sizes' => array( '6','12','14','16','20' ),
		'faces' => array( 'Helvetica Neue' => 'Helvetica Neue','Arial' => 'Arial' ),
		'styles' => array( 'normal' => 'Normal','bold' => 'Bold' ),
		'color' => false
	);

	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}

	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}


	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages( 'sort_column=post_parent,menu_order' );
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/images/';

	$options = array();

	$options[] = array(
		'name' => __( '文字设置', 'theme-textdomain' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __( '网站标题', 'theme-textdomain' ),
		'id' => 'title',
		'std' => 'Hi！小姐姐！',
		'class' => 'mini',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( '想要对小姐姐说的话', 'theme-textdomain' ),
		'desc' => __( '例如：小姐姐！其实其实...我喜欢你很久了！小姐姐做我对象好不好？！', 'theme-textdomain' ),
		'id' => 'talk',
		'type' => 'editor',
		'settings' => $wp_editor_settings
	);
	
	$options[] = array(
		'name' => __( '按钮1', 'theme-textdomain' ),
		'id' => 'button_1',
		'std' => '好',
		'class' => 'mini',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( '按钮1', 'theme-textdomain' ),
		'id' => 'button_2',
		'std' => '不好',
		'class' => 'mini',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( '图片设置', 'theme-textdomain' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __( '给小姐姐看的一张图片', 'theme-textdomain' ),
		'desc' => __( '要可爱，只能说这么多啦...', 'theme-textdomain' ),
		'id' => 'pic',
		'type' => 'upload'
	);
	
	$options[] = array(
		'name' => __( '更多设置', 'theme-textdomain' ),
		'type' => 'heading'
	);
	
	$options[] = array(
		'name' => __( '统计代码', 'theme-textdomain' ),
		'id' => 'tj',
		'desc' => __( '请填写<a href="https://web.umeng.com/main.php?c=site&a=show">CNZZ</a>的站点id，不懂移步到这里：<a href="https://wpxzt.com/themes/girl.html">https://wpxzt.com/themes/girl.html</a>', 'theme-textdomain' ),
		'class' => 'mini',
		'type' => 'text'
	);
	
	$options[] = array(
		'name' => __( '网易云音乐', 'theme-textdomain' ),
		'id' => 'music',
		'desc' => __( '请填写<a href="https://music.163.com/">网易云音乐</a>的音乐id，不懂移步到这里：<a href="https://wpxzt.com/themes/girl.html">https://wpxzt.com/themes/girl.html</a>', 'theme-textdomain' ),
		'class' => 'mini',
		'type' => 'text'
	);
	
	return $options;
}